#!/bin/bash
# Exit immediately on error
set -eu -o pipefail

SOFTWARE=vsearch
VERSION=2.3.4
ARCHIVE=v${VERSION}.tar.gz
ARCHIVE_URL=https://github.com/torognes/$SOFTWARE/archive/$ARCHIVE
SOFTWARE_DIR=${SOFTWARE}-${VERSION}

# Specific commands to extract and build the software
# $INSTALL_DIR and $INSTALL_DOWNLOAD have been set automatically
# $ARCHIVE has been downloaded in $INSTALL_DOWNLOAD
build() {
  cd $INSTALL_DOWNLOAD
  tar zxvf $ARCHIVE

  # Install software
  cd $SOFTWARE_DIR
  ./autogen.sh
  ./configure --prefix=$INSTALL_DIR/${SOFTWARE_DIR}
  make
  make install
}

module_file() {
echo "\
#%Module1.0
proc ModulesHelp { } {
  puts stderr \"\tMUGQIC - $SOFTWARE \"
}
module-whatis \"$SOFTWARE\"

set             root                $INSTALL_DIR/$SOFTWARE_DIR
setenv		VSEARCH_HOME        \$root 
prepend-path	PATH                \$root
"
}

# Call generic module install script once all variables and functions have been set
MODULE_INSTALL_SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
source $MODULE_INSTALL_SCRIPT_DIR/install_module.sh $@
